Index: net/proxy/proxy_script_fetcher_impl.cc |
diff --git a/net/proxy/proxy_script_fetcher_impl.cc b/net/proxy/proxy_script_fetcher_impl.cc |
index 0a54046cc5e0d40265cbe2cd3132794215adcf0b..0724127b7498e6793fbeb7f79c8229656dd7d309 100644 |
--- a/net/proxy/proxy_script_fetcher_impl.cc |
+++ b/net/proxy/proxy_script_fetcher_impl.cc |
@@ -1,4 +1,4 @@ |
-// Copyright (c) 2010 The Chromium Authors. All rights reserved. |
+// Copyright (c) 2011 The Chromium Authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
@@ -70,7 +70,7 @@ void ConvertResponseToUTF16(const std::string& charset, |
} // namespace |
ProxyScriptFetcherImpl::ProxyScriptFetcherImpl( |
- URLRequestContext* url_request_context) |
+ net::URLRequestContext* url_request_context) |
wtc
2011/01/15 17:54:23
Undo the changes to this file (already in the 'net
|
: ALLOW_THIS_IN_INITIALIZER_LIST(task_factory_(this)), |
url_request_context_(url_request_context), |
buf_(new net::IOBuffer(kBufSize)), |
@@ -134,7 +134,7 @@ void ProxyScriptFetcherImpl::Cancel() { |
ResetCurRequestState(); |
} |
-URLRequestContext* ProxyScriptFetcherImpl::GetRequestContext() { |
+net::URLRequestContext* ProxyScriptFetcherImpl::GetRequestContext() { |
return url_request_context_; |
} |
@@ -260,9 +260,9 @@ void ProxyScriptFetcherImpl::FetchCompleted() { |
int result_code = result_code_; |
CompletionCallback* callback = callback_; |
- // Hold a reference to the URLRequestContext to prevent re-entrancy from |
- // ~URLRequestContext. |
- scoped_refptr<URLRequestContext> context(cur_request_->context()); |
+ // Hold a reference to the net::URLRequestContext to prevent re-entrancy from |
+ // ~net::URLRequestContext. |
+ scoped_refptr<net::URLRequestContext> context(cur_request_->context()); |
ResetCurRequestState(); |
callback->Run(result_code); |